import { Component, OnInit } from '@angular/core';
import { RoomService } from '../../../services/http/room.service';
import { ActivatedRoute } from '@angular/router';
import { RoomPageComponent } from '../room-page/room-page.component';
import { Room } from '../../../models/room';
import { Location } from '@angular/common';
import { NotificationService } from '../../../services/util/notification.service';
import { MatDialog } from '@angular/material';
import { RoomDeleteComponent } from '../../dialogs/room-delete/room-delete.component';
import { RoomEditComponent } from '../../dialogs/room-edit/room-edit.component';

@Component({
  selector: 'app-room-creator-page',
  templateUrl: './room-creator-page.component.html',
  styleUrls: ['./room-creator-page.component.scss']
})
export class RoomCreatorPageComponent extends RoomPageComponent implements OnInit {
  room: Room;
  updRoom: Room;

  constructor(protected roomService: RoomService,
              protected notification: NotificationService,
              protected route: ActivatedRoute,
              protected location: Location,
              public dialog: MatDialog
            ) {
    super(roomService, route, location);
  }

  ngOnInit() {
    this.route.params.subscribe(params => {
      this.getRoom(params['roomId']);
    });
  }

  goBack(): void {
    this.location.back();
  }

  updateRoom(): void {
    if ((this.updRoom.name === this.room.name) &&
      (this.updRoom.shortId === this.room.shortId) &&
      (this.updRoom.description === this.room.description)
    ) {
      this.notification.show('There were no changes');
      return;
    } else {
      this.notification.show('Changes are made');
      this.room.name = this.updRoom.name;
      this.room.shortId = this.updRoom.shortId;
      this.room.description = this.updRoom.description;
      this.roomService.updateRoom(this.room)
        .subscribe();
    }
  }

  deleteRoom(room: Room): void {
    const msg = room.name + ' deleted';
    this.notification.show(msg);
    this.delete(room);
  }

  confirmDeletion(dialogAnswer: string): void {
    if (dialogAnswer === 'delete') {
      this.deleteRoom(this.room);
    }
  }

  openDeletionRoomDialog(): void {
    const dialogRef = this.dialog.open(RoomDeleteComponent, {
      width: '400px'
    });
    dialogRef.componentInstance.room = this.room;
    dialogRef.afterClosed()
      .subscribe(result => {
        this.confirmDeletion(result);
      });
  }

  showEditDialog(): void {
    this.updRoom = new Room();
    this.updRoom.name = this.room.name;
    this.updRoom.shortId = this.room.shortId;
    this.updRoom.description = this.room.description;
    const dialogRef = this.dialog.open(RoomEditComponent, {
      width: '400px'
    });
    dialogRef.componentInstance.editRoom = this.updRoom;
    dialogRef.afterClosed()
      .subscribe(result => {
        if (result === 'abort') {
          return;
        }
        if (result === 'edit') {
          this.updateRoom();
        }
      });
  }
}

